==> qtjambi-sensors-5.15.14-sources.jar: io/qt/sensors/QIRProximityReading.java <==
package io.qt.sensors;

import io.qt.*;


/**
 * <p>Holds readings from the IR proximity sensor</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qirproximityreading.html">QIRProximityReading</a></p>
 */
public class QIRProximityReading extends io.qt.sensors.QSensorReading
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QIRProximityReading.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QIRProximityReading() {
        this((io.qt.core.QObject)null);
    }
    
    public QIRProximityReading(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QIRProximityReading instance, io.qt.core.QObject parent);
    
    /**
     * <p>Kotlin property getter. In Java use {@link #reflectance()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final double getReflectance() {
        return reflectance();
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qirproximityreading.html#reflectance-prop">QIRProximityReading::reflectance()const</a></p>
     */
    @QtPropertyReader(name="reflectance")
    @QtUninvokable
    public final double reflectance(){
        return reflectance_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native double reflectance_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qirproximityreading.html#setReflectance">QIRProximityReading::setReflectance(qreal)</a></p>
     */
    @QtUninvokable
    public final void setReflectance(double reflectance){
        setReflectance_native_qreal(QtJambi_LibraryUtilities.internal.nativeId(this), reflectance);
    }
    
    @QtUninvokable
    private native void setReflectance_native_qreal(long __this__nativeId, double reflectance);
    
    @QtUninvokable
    protected void copyValuesFrom(io.qt.sensors.@Nullable QSensorReading other){
        copyValuesFrom_native_QSensorReading_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @QtUninvokable
    private native void copyValuesFrom_native_QSensorReading_ptr(long __this__nativeId, long other);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QIRProximityReading(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QIRProximityReading(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QIRProximityReading instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-sensors-6.2.7-sources.jar: io/qt/sensors/QIRProximityReading.java <==
package io.qt.sensors;


/**
 * <p>Java wrapper for Qt class QIRProximityReading</p>
 */
public class QIRProximityReading extends io.qt.sensors.QSensorReading
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QIRProximityReading.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QIRProximityReading(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QIRProximityReading() {
        this((io.qt.core.QObject)null);
    }
    
    public QIRProximityReading(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QIRProximityReading instance, io.qt.core.QObject parent);
    
    @io.qt.QtPropertyReader(name="reflectance")
    @io.qt.QtUninvokable
    public final double reflectance(){
        return reflectance_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native double reflectance_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void setReflectance(double reflectance){
        setReflectance_native_qtjambireal(QtJambi_LibraryUtilities.internal.nativeId(this), reflectance);
    }
    
    @io.qt.QtUninvokable
    private native void setReflectance_native_qtjambireal(long __this__nativeId, double reflectance);
    
    @io.qt.QtUninvokable
    protected void copyValuesFrom(io.qt.sensors.QSensorReading other){
        copyValuesFrom_native_QSensorReading_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @io.qt.QtUninvokable
    private native void copyValuesFrom_native_QSensorReading_ptr(long __this__nativeId, long other);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QIRProximityReading(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QIRProximityReading(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QIRProximityReading instance, QDeclarativeConstructor constructor);
    
}
